Extract summary statistics from the result of a BuyseTest function.
# S4 method for BuyseRes
coef(object, statistic = NULL, stratified = FALSE,
cumulative = TRUE, ...)output of BuyseTest
[character] the type of summary statistic. See the detail section.
[logical] should the summary statistic be strata-specific? Otherwise a summary statistic over all strata is returned.
[logical] should the score be cumulated over endpoints? Otherwise display the contribution of each endpoint.
ignored.
One of the following statistic can be specified:
"netBenefit": returns the net benefit.
"winRatio": returns the win ratio.
"count.favorable": returns the number of pairs in favor of the treatment.
"count.unfavorable": returns the number of pairs in favor of the control.
"count.neutral": returns the number of neutral pairs.
"count.uninf": returns the number of uninformative pairs.
"pc.favorable": returns the percentage of pairs in favor of the treatment, i.e. \(P[X \geq Y + \tau]\).
"pc.unfavorable": returns the percentage of pairs in favor of the control, i.e. \(P[Y \geq X + \tau]\).
"pc.neutral": returns the percentage of neutral pairs.
"pc.uninf": returns the percentage of uninformative pairs.