Extract summary statistics from the result of a BuyseTest function.
# S4 method for S4BuyseTest
coef(
object,
endpoint = NULL,
statistic = NULL,
stratified = FALSE,
cumulative = NULL,
resampling = FALSE,
...
)When resampling=FALSE and stratified=FALSE, return a numeric vector.
When resampling=FALSE and stratified=TRUE, return a matrix.
When resampling=TRUE and stratified=FALSE, return a matrix.
When resampling=TRUE and stratified=TRUE, return an 3-dimensional array.
output of BuyseTest
[character] for which endpoint(s) the summary statistic should be output?
If NULL returns the summary statistic for all endpoints.
[character] the type of summary statistic. See the detail section.
[logical] should the summary statistic be strata-specific? Otherwise a summary statistic over all strata is returned.
[logical] should the summary statistic be cumulated over endpoints? Otherwise display the contribution of each endpoint.
[logical] should the summary statistic obtained by resampling be output?
ignored.
Brice Ozenne
One of the following statistic can be specified:
"netBenefit": returns the net benefit.
"winRatio": returns the win ratio.
"favorable": returns the proportion in favor of the treatment (also called Mann-Whitney parameter).
"unfavorable": returns the proportion in favor of the control.
"unfavorable": returns the proportion of neutral pairs.
"unfavorable": returns the proportion of uninformative pairs.
"count.favorable": returns the number of pairs in favor of the treatment.
"count.unfavorable": returns the number of pairs in favor of the control.
"count.neutral": returns the number of neutral pairs.
"count.uninf": returns the number of uninformative pairs.