Extract uncertainty about the summary statistics (net benefit, win ratio, ...) from GPC.
# S4 method for S4BuyseTest
vcov(
object,
endpoint = NULL,
statistic = NULL,
strata = FALSE,
cumulative = TRUE,
...
)A numeric matrix.
a S4BuyseTest object, output of BuyseTest.
[character] for which endpoint(s) the variance-covariance matrix should be output?
If NULL consider all endpoints.
[character] the type of summary statistic. See the detail section.
[character vector] the strata relative to which the variance-covariance matrix should be output.
Can also be "global" or FALSE to output the statistic pooled over all strata.
[logical] should the summary statistic be cumulated over endpoints? Otherwise display the contribution of each endpoint.
ignored.
Brice Ozenne
When consider a second order H-decomposition, it is only used to estimate variance: the correlation between endpoints is evaluated using the first order H-decomposition.